==> dde-shell_2.0.15.tar.xz: BUILD/panels/dock/taskmanager/translations/org.deepin.ds.dock.taskmanager_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Telakka</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Pakota lopetus</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Sulje kaikki</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Telakka</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Pakota lopetus</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Sulje kaikki</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/dock/taskmanager/translations/org.deepin.ds.dock.taskmanager_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Siirrä roskakoriin</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Telakka</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Pakota lopetus</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Sulje kaikki</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Telakka</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Pakota lopetus</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Sulje kaikki</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 tiedostoa</translation>
    </message>
</context>
</TS>
